@@ -27,6 +27,8 @@
 
 #include <unistd.h>
 #include <string.h>
+#include <libxml/globals.h>
+#include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <gdk/gdk.h>
 
@@ -213,7 +215,6 @@ is_unique (EggToolbarsModel *model,
   EggToolbarsItem *idata2;
   GNode *toolbar, *item;
 
-
   for(toolbar = g_node_first_child (model->priv->toolbars);
       toolbar != NULL; toolbar = g_node_next_sibling (toolbar))
     {
@@ -330,7 +331,6 @@ egg_toolbars_model_set_flags (EggToolbarsModel *model,
 		 0, toolbar_position);
 }
 
-
 char *
 egg_toolbars_model_get_data (EggToolbarsModel *model,
                              GdkAtom           type,
