@@ -35,6 +35,7 @@
 #include <time.h>
 
 #include "eom-exif-util.h"
+#include "eom-util.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -94,9 +95,15 @@ _calculate_wday_yday (struct tm *tm)
 	tm->tm_yday = tmp_tm.tm_yday;
 }
 
+/* Older GCCs don't support pragma diagnostic inside functions.
+ * Put these here to avoid problems with the strftime format strings
+ * without breaking the build for these older GCCs */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+
 #ifdef HAVE_STRPTIME
 static gchar *
-eom_exif_util_format_date_with_strptime (const gchar *date)
+eom_exif_util_format_date_with_strptime (const gchar *date, const gchar* format)
 {
 	static GOnce strptime_updates_wday = G_ONCE_INIT;
 	gchar *new_date = NULL;
@@ -118,7 +125,7 @@ eom_exif_util_format_date_with_strptime (const gchar *date)
 			_calculate_wday_yday (&tm);
 
 		/* A strftime-formatted string, to display the date the image was taken.  */
-		dlen = strftime (tmp_date, DATE_BUF_SIZE * sizeof(gchar), _("%a, %d %B %Y  %X"), &tm);
+		dlen = strftime (tmp_date, DATE_BUF_SIZE * sizeof(gchar), format, &tm);
 		new_date = g_strndup (tmp_date, dlen);
 	}
 
@@ -126,7 +133,7 @@ eom_exif_util_format_date_with_strptime (const gchar *date)
 }
 #else
 static gchar *
-eom_exif_util_format_date_by_hand (const gchar *date)
+eom_exif_util_format_date_by_hand (const gchar *date, const gchar* format)
 {
 	int year, month, day, hour, minutes, seconds;
 	int result;
@@ -140,7 +147,6 @@ eom_exif_util_format_date_by_hand (const gchar *date)
 	} else {
 		gchar tmp_date[DATE_BUF_SIZE];
 		gsize dlen;
-		time_t secs;
 		struct tm tm;
 
 		memset (&tm, '\0', sizeof (tm));
@@ -150,16 +156,10 @@ eom_exif_util_format_date_by_hand (const gchar *date)
 		// Calculate tm.tm_wday
 		_calculate_wday_yday (&tm);
 
-		if (result < 5) {
-		  	/* A strftime-formatted string, to display the date the image was taken, for the case we don't have the time.  */
-			dlen = strftime (tmp_date, DATE_BUF_SIZE * sizeof(gchar), _("%a, %d %B %Y"), &tm);
-		} else {
-			tm.tm_sec = result < 6 ? 0 : seconds;
-			tm.tm_min = minutes;
-			tm.tm_hour = hour;
-			/* A strftime-formatted string, to display the date the image was taken.  */
-			dlen = strftime (tmp_date, DATE_BUF_SIZE * sizeof(gchar), _("%a, %d %B %Y  %X"), &tm);
-		}
+		tm.tm_sec = result < 6 ? 0 : seconds;
+		tm.tm_min = result < 5 ? 0 : minutes;
+		tm.tm_hour = result < 4 ? 0 : hour;
+		dlen = strftime (tmp_date, DATE_BUF_SIZE * sizeof(gchar), format, &tm);
 
 		if (dlen == 0)
 			return NULL;
@@ -170,6 +170,8 @@ eom_exif_util_format_date_by_hand (const gchar *date)
 }
 #endif /* HAVE_STRPTIME */
 
+#pragma GCC diagnostic pop
+
 /**
  * eom_exif_util_format_date:
  * @date: a date string following Exif specifications
@@ -185,13 +187,131 @@ eom_exif_util_format_date (const gchar *date)
 {
 	gchar *new_date;
 #ifdef HAVE_STRPTIME
-	new_date = eom_exif_util_format_date_with_strptime (date);
+	/* A strftime-formatted string, to display the date the image was taken.  */
+	new_date = eom_exif_util_format_date_with_strptime (date, _("%a, %d %B %Y  %X"));
 #else
-	new_date = eom_exif_util_format_date_by_hand (date);
+	new_date = eom_exif_util_format_date_by_hand (date, _("%a, %d %B %Y  %X"));
 #endif /* HAVE_STRPTIME */
 	return new_date;
 }
 
+void
+eom_exif_util_set_label_text (GtkLabel *label,
+			      EomExifData *exif_data,
+			      gint tag_id)
+{
+	gchar exif_buffer[512];
+	const gchar *buf_ptr;
+	gchar *label_text = NULL;
+
+	g_return_if_fail (GTK_IS_LABEL (label));
+
+	if (exif_data) {
+		buf_ptr = eom_exif_data_get_value (exif_data, tag_id,
+						   exif_buffer, 512);
+
+		if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
+			label_text = eom_exif_util_format_date (buf_ptr);
+		else
+			label_text = eom_util_make_valid_utf8 (buf_ptr);
+	}
+
+	gtk_label_set_text (label, label_text);
+	g_free (label_text);
+}
+
+void
+eom_exif_util_format_datetime_label (GtkLabel *label, EomExifData *exif_data,
+                                     gint tag_id, const gchar *format)
+{
+	gchar exif_buffer[512];
+	const gchar *buf_ptr;
+	gchar *label_text = NULL;
+
+	g_return_if_fail (GTK_IS_LABEL (label));
+	g_warn_if_fail (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL);
+
+	if (exif_data) {
+	    buf_ptr = eom_exif_data_get_value (exif_data, tag_id,
+	                                       exif_buffer, 512);
+
+	    if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
+#ifdef HAVE_STRPTIME
+	        label_text = eom_exif_util_format_date_with_strptime (buf_ptr, format);
+#else
+	        label_text = eom_exif_util_format_date_by_hand (buf_ptr, format);
+#endif /* HAVE_STRPTIME */
+	}
+
+	gtk_label_set_text (label, label_text);
+	g_free (label_text);
+}
+
+void
+eom_exif_util_set_focal_length_label_text (GtkLabel *label,
+					   EomExifData *exif_data)
+{
+	ExifEntry *entry = NULL, *entry35mm = NULL;
+	ExifByteOrder byte_order;
+	gfloat f_val = 0.0;
+	gchar *fl_text = NULL,*fl35_text = NULL;
+
+	/* If no ExifData is supplied the label will be
+	 * cleared later as fl35_text is NULL. */
+	if (exif_data != NULL) {
+		entry = exif_data_get_entry (exif_data, EXIF_TAG_FOCAL_LENGTH);
+		entry35mm = exif_data_get_entry (exif_data,
+					    EXIF_TAG_FOCAL_LENGTH_IN_35MM_FILM);
+		byte_order = exif_data_get_byte_order (exif_data);
+	}
+
+	if (entry && G_LIKELY (entry->format == EXIF_FORMAT_RATIONAL)) {
+		ExifRational value;
+
+		/* Decode value by hand as libexif is not necessarily returning
+		 * it in the format we want it to be.
+		 */
+		value = exif_get_rational (entry->data, byte_order);
+		/* Guard against div by zero */
+		if (G_LIKELY(value.denominator != 0))
+			f_val = (gfloat)value.numerator/
+				(gfloat)value.denominator;
+
+		/* TRANSLATORS: This is the actual focal length used when
+		   the image was taken.*/
+		fl_text = g_strdup_printf (_("%.1f (lens)"), f_val);
+
+	}
+	if (entry35mm && G_LIKELY (entry35mm->format == EXIF_FORMAT_SHORT)) {
+		ExifShort s_val;
+
+		s_val = exif_get_short (entry35mm->data, byte_order);
+
+		/* Print as float to get a similar look as above. */
+		/* TRANSLATORS: This is the equivalent focal length assuming
+		   a 35mm film camera. */
+		fl35_text = g_strdup_printf(_("%.1f (35mm film)"),(float)s_val);
+	}
+
+	if (fl_text) {
+		if (fl35_text) {
+			gchar *merged_txt;
+
+			merged_txt = g_strconcat (fl35_text,", ", fl_text, NULL);
+			gtk_label_set_text (label, merged_txt);
+			g_free (merged_txt);
+		} else {
+			gtk_label_set_text (label, fl_text);
+		}
+	} else {
+		/* This will also clear the label if no ExifData was supplied */
+		gtk_label_set_text (label, fl35_text);
+	}
+
+	g_free (fl35_text);
+	g_free (fl_text);
+}
+
 /**
  * eom_exif_data_get_value:
  * @exif_data: pointer to an <structname>ExifData</structname> struct
