@@ -33,9 +33,6 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#define EOM_JOB_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_JOB, EomJobPrivate))
-
 G_DEFINE_TYPE (EomJob, eom_job, G_TYPE_OBJECT);
 G_DEFINE_TYPE (EomJobThumbnail, eom_job_thumbnail, EOM_TYPE_JOB);
 G_DEFINE_TYPE (EomJobLoad, eom_job_load, EOM_TYPE_JOB);
@@ -443,11 +440,8 @@ eom_job_model_run (EomJob *ejob)
 
 	eom_list_store_add_files (job->store, filtered_list);
 
-	g_list_foreach (filtered_list, (GFunc) g_object_unref, NULL);
-	g_list_free (filtered_list);
-
-	g_list_foreach (error_list, (GFunc) g_free, NULL);
-	g_list_free (error_list);
+	g_list_free_full (filtered_list, g_object_unref);
+	g_list_free_full (error_list, g_free);
 
 	ejob->finished = TRUE;
 }
@@ -466,8 +460,7 @@ eom_job_transform_dispose (GObject *object)
 		job->trans = NULL;
 	}
 
-	g_list_foreach (job->images, (GFunc) g_object_unref, NULL);
-	g_list_free (job->images);
+	g_list_free_full (job->images, g_object_unref);
 
 	(* G_OBJECT_CLASS (eom_job_transform_parent_class)->dispose) (object);
 }
@@ -566,8 +559,7 @@ eom_job_save_dispose (GObject *object)
 	job = EOM_JOB_SAVE (object);
 
 	if (job->images) {
-		g_list_foreach (job->images, (GFunc) g_object_unref, NULL);
-		g_list_free (job->images);
+		g_list_free_full (job->images, g_object_unref);
 		job->images = NULL;
 	}
 
@@ -659,8 +651,7 @@ eom_job_save_run (EomJob *ejob)
 			}
 		}
 
-		handler_id = g_signal_connect (G_OBJECT (image),
-					       "save-progress",
+		handler_id = g_signal_connect (image, "save-progress",
 				               G_CALLBACK (save_progress_handler),
 					       job);
 
@@ -674,7 +665,7 @@ eom_job_save_run (EomJob *ejob)
 			g_object_unref (save_info);
 
 		if (handler_id != 0)
-			g_signal_handler_disconnect (G_OBJECT (image), handler_id);
+			g_signal_handler_disconnect (image, handler_id);
 
 		eom_image_data_unref (image);
 
@@ -790,8 +781,7 @@ eom_job_save_as_run (EomJob *ejob)
 
 		g_assert (ejob->error == NULL);
 
-		handler_id = g_signal_connect (G_OBJECT (image),
-					       "save-progress",
+		handler_id = g_signal_connect (image, "save-progress",
 				               G_CALLBACK (save_progress_handler),
 					       job);
 
@@ -837,7 +827,7 @@ eom_job_save_as_run (EomJob *ejob)
 			g_object_unref (dest_info);
 
 		if (handler_id != 0)
-			g_signal_handler_disconnect (G_OBJECT (image), handler_id);
+			g_signal_handler_disconnect (image, handler_id);
 
 		eom_image_data_unref (image);
 
