@@ -263,12 +263,16 @@ eom_metadata_sidebar_set_image (EomMetadataSidebar *sidebar, EomImage *image)
 	if (image == priv->image)
 		return;
 
-
+#if GLIB_CHECK_VERSION(2,62,0)
+	g_clear_signal_handler (&priv->thumb_changed_id,
+	                        priv->image);
+#else
 	if (priv->thumb_changed_id != 0) {
 		g_signal_handler_disconnect (priv->image,
 					     priv->thumb_changed_id);
 		priv->thumb_changed_id = 0;
 	}
+#endif
 
 	if (priv->image)
 		g_object_unref (priv->image);
@@ -525,7 +529,6 @@ eom_metadata_sidebar_class_init (EomMetadataSidebarClass *klass)
 #endif /* HAVE_METADATA */
 }
 
-
 GtkWidget*
 eom_metadata_sidebar_new (EomWindow *window)
 {
